@@ -20,29 +20,44 @@
   USA.
 ***/
 
-#include <condition_variable>
-#include <mutex>
-
 #include <pulse/pulseaudio.h>
 
-#include <libaudcore/runtime.h>
-#include <libaudcore/plugin.h>
 #include <libaudcore/i18n.h>
-
-using scoped_lock = std::unique_lock<std::mutex>;
+#include <libaudcore/plugin.h>
+#include <libaudcore/runtime.h>
+#include <libaudcore/threads.h>
+#include <libaudcore/preferences.h>
 
 class PulseOutput : public OutputPlugin
 {
 public:
     static const char about[];
+    static const PreferencesWidget widgets[];
+    static const PluginPreferences prefs;
+    static const char * const prefs_defaults[];
+    static const String default_context_name;
+    static const String default_stream_name;
 
     static constexpr PluginInfo info = {
         N_("PulseAudio Output"),
         PACKAGE,
-        about
+        about,
+        & prefs
     };
 
-    constexpr PulseOutput () : OutputPlugin (info, 8) {}
+    /*
+     * Set a higher priority to that of PipeWire. Under a PulseAudio setup,
+     * the PipeWire output may be selected by default, which would promptly
+     * fail to work, as there is no PipeWire server/proxy running.
+     *
+     * On the other hand, under a PipeWire setup, PulseAudio output would
+     * still work normally, as pipewire-pulse acts as a PulseAudio server.
+     *
+     * Making PulseAudio the top preference allows for better compatibility
+     * for different setups, especially for distributions that have not (yet)
+     * switched to PipeWire as the default audio server.
+     */
+    constexpr PulseOutput () : OutputPlugin (info, 9) {}
 
     bool init ();
     void cleanup ();
@@ -65,8 +80,26 @@ public:
 
 EXPORT PulseOutput aud_plugin_instance;
 
-static std::mutex pulse_mutex;
-static std::condition_variable pulse_cond;
+const PreferencesWidget PulseOutput::widgets[] = {
+    WidgetEntry (N_("Context name:"),
+        WidgetString ("pulse", "context_name")),
+    WidgetEntry (N_("Stream name:"),
+        WidgetString ("pulse", "stream_name")),
+};
+
+const PluginPreferences PulseOutput::prefs = {{widgets}};
+
+const String PulseOutput::default_context_name = String ("Audacious");
+const String PulseOutput::default_stream_name = String ("Audacious");
+
+const char * const PulseOutput::prefs_defaults[] = {
+    "context_name", PulseOutput::default_context_name,
+    "stream_name", PulseOutput::default_stream_name,
+    nullptr
+};
+
+static aud::mutex pulse_mutex;
+static aud::condvar pulse_cond;
 
 static pa_context * context = nullptr;
 static pa_stream * stream = nullptr;
@@ -89,7 +122,7 @@ static bool alive ()
 /* Cooperative polling method.  Only one thread calls the actual poll function,
  * and dispatches the events received.  Any other threads simply wait for the
  * first thread to finish. */
-static void poll_events (scoped_lock & lock)
+static void poll_events (aud::mutex::holder & lock)
 {
     if (polling)
         pulse_cond.wait (lock);
@@ -113,7 +146,7 @@ static void poll_events (scoped_lock & lock)
 
 /* Wait for an asynchronous operation to complete.  Return immediately if the
  * connection dies. */
-static bool finish (pa_operation * op, scoped_lock & lock)
+static bool finish (pa_operation * op, aud::mutex::holder & lock)
 {
     pa_operation_state_t state;
     while ((state = pa_operation_get_state (op)) != PA_OPERATION_DONE && alive ())
@@ -174,7 +207,7 @@ static void context_success_cb (pa_context *, int success, void * userdata)
         * (int * ) userdata = success;
 }
 
-static void get_volume_locked ()
+static void get_volume_locked (aud::mutex::holder & lock)
 {
     if (! polling)
     {
@@ -199,15 +232,15 @@ static void get_volume_locked ()
 
 StereoVolume PulseOutput::get_volume ()
 {
-    scoped_lock lock (pulse_mutex);
+    auto lock = pulse_mutex.take ();
 
     if (connected)
-        get_volume_locked ();
+        get_volume_locked (lock);
 
     return saved_volume;
 }
 
-static void set_volume_locked (scoped_lock & lock)
+static void set_volume_locked (aud::mutex::holder & lock)
 {
     if (volume.channels != 1)
     {
@@ -231,7 +264,7 @@ static void set_volume_locked (scoped_lock & lock)
 
 void PulseOutput::set_volume (StereoVolume v)
 {
-    scoped_lock lock (pulse_mutex);
+    auto lock = pulse_mutex.take ();
 
     saved_volume = v;
     saved_volume_changed = true;
@@ -242,7 +275,7 @@ void PulseOutput::set_volume (StereoVolume v)
 
 void PulseOutput::pause (bool pause)
 {
-    scoped_lock lock (pulse_mutex);
+    auto lock = pulse_mutex.take ();
 
     int success = 0;
     CHECK (pa_stream_cork, stream, pause, stream_success_cb);
@@ -250,7 +283,7 @@ void PulseOutput::pause (bool pause)
 
 int PulseOutput::get_delay ()
 {
-    scoped_lock lock (pulse_mutex);
+    auto lock = pulse_mutex.take ();
 
     pa_usec_t usec;
     int neg;
@@ -263,7 +296,7 @@ int PulseOutput::get_delay ()
 
 void PulseOutput::drain ()
 {
-    scoped_lock lock (pulse_mutex);
+    auto lock = pulse_mutex.take ();
 
     int success = 0;
     CHECK (pa_stream_drain, stream, stream_success_cb);
@@ -271,7 +304,7 @@ void PulseOutput::drain ()
 
 void PulseOutput::flush ()
 {
-    scoped_lock lock (pulse_mutex);
+    auto lock = pulse_mutex.take ();
 
     int success = 0;
     CHECK (pa_stream_flush, stream, stream_success_cb);
@@ -284,7 +317,7 @@ void PulseOutput::flush ()
 
 void PulseOutput::period_wait ()
 {
-    scoped_lock lock (pulse_mutex);
+    auto lock = pulse_mutex.take ();
 
     int success = 0;
     CHECK (pa_stream_trigger, stream, stream_success_cb);
@@ -296,7 +329,7 @@ void PulseOutput::period_wait ()
 
 int PulseOutput::write_audio (const void * ptr, int length)
 {
-    scoped_lock lock (pulse_mutex);
+    auto lock = pulse_mutex.take ();
     int ret = 0;
 
     length = aud::min ((size_t) length, pa_stream_writable_size (stream));
@@ -310,7 +343,7 @@ int PulseOutput::write_audio (const void * ptr, int length)
     return ret;
 }
 
-static void close_audio_locked (scoped_lock & lock)
+static void close_audio_locked (aud::mutex::holder & lock)
 {
     /* wait for any parallel tasks (e.g. set_volume()) to complete */
     while (polling)
@@ -341,7 +374,7 @@ static void close_audio_locked (scoped_lock & lock)
 
 void PulseOutput::close_audio ()
 {
-    scoped_lock lock (pulse_mutex);
+    auto lock = pulse_mutex.take ();
     close_audio_locked (lock);
 }
 
@@ -379,7 +412,7 @@ static bool set_sample_spec (pa_sample_spec & ss, int fmt, int rate, int nch)
 
 static void set_buffer_attr (pa_buffer_attr & buffer, const pa_sample_spec & ss)
 {
-    int buffer_ms = aud_get_int (nullptr, "output_buffer_size");
+    int buffer_ms = aud_get_int ("output_buffer_size");
     size_t buffer_size = pa_usec_to_bytes ((pa_usec_t) 1000 * buffer_ms, & ss);
 
     buffer.maxlength = (uint32_t) -1;
@@ -389,7 +422,17 @@ static void set_buffer_attr (pa_buffer_attr & buffer, const pa_sample_spec & ss)
     buffer.fragsize = buffer_size;
 }
 
-static bool create_context (scoped_lock & lock)
+static String get_context_name ()
+{
+    String context_name = aud_get_str ("pulse", "context_name");
+    if (context_name == String (""))
+    {
+        return PulseOutput::default_context_name;
+    }
+    return context_name;
+}
+
+static bool create_context (aud::mutex::holder & lock)
 {
     if (! (mainloop = pa_mainloop_new ()))
     {
@@ -397,7 +440,16 @@ static bool create_context (scoped_lock & lock)
         return false;
     }
 
-    if (! (context = pa_context_new (pa_mainloop_get_api (mainloop), "Audacious")))
+    pa_proplist * proplist = pa_proplist_new ();
+    pa_proplist_sets (proplist, PA_PROP_APPLICATION_ID, "audacious");
+    pa_proplist_sets (proplist, PA_PROP_APPLICATION_ICON_NAME, "audacious");
+
+    context = pa_context_new_with_proplist (pa_mainloop_get_api (mainloop),
+     get_context_name (), proplist);
+
+    pa_proplist_free (proplist);
+
+    if (! context)
     {
         AUDERR ("Failed to allocate context\n");
         return false;
@@ -425,9 +477,19 @@ static bool create_context (scoped_lock & lock)
     return true;
 }
 
-static bool create_stream (scoped_lock & lock, const pa_sample_spec & ss)
+static String get_stream_name ()
 {
-    if (! (stream = pa_stream_new (context, "Audacious", & ss, nullptr)))
+    String stream_name = aud_get_str ("pulse", "stream_name");
+    if (stream_name == String (""))
+    {
+        return PulseOutput::default_stream_name;
+    }
+    return stream_name;
+}
+
+static bool create_stream (aud::mutex::holder & lock, const pa_sample_spec & ss)
+{
+    if (! (stream = pa_stream_new (context, get_stream_name (), & ss, nullptr)))
     {
         REPORT ("pa_stream_new");
         return false;
@@ -460,7 +522,7 @@ static bool create_stream (scoped_lock & lock, const pa_sample_spec & ss)
     return true;
 }
 
-static bool subscribe_events (scoped_lock & lock)
+static bool subscribe_events (aud::mutex::holder & lock)
 {
     pa_context_set_subscribe_callback (context, subscribe_cb, nullptr);
 
@@ -481,7 +543,7 @@ static bool subscribe_events (scoped_lock & lock)
 
 bool PulseOutput::open_audio (int fmt, int rate, int nch, String & error)
 {
-    scoped_lock lock (pulse_mutex);
+    auto lock = pulse_mutex.take ();
 
     pa_sample_spec ss;
     if (! set_sample_spec (ss, fmt, rate, nch))
@@ -501,13 +563,15 @@ bool PulseOutput::open_audio (int fmt, int rate, int nch, String & error)
     if (saved_volume_changed)
         set_volume_locked (lock);
     else
-        get_volume_locked ();
+        get_volume_locked (lock);
 
     return true;
 }
 
 bool PulseOutput::init ()
 {
+    aud_config_set_defaults ("pulse", prefs_defaults);
+
     /* check for a running server and get initial volume */
     String error;
     if (! open_audio (FMT_S16_NE, 44100, 2, error))
