@@ -23,6 +23,7 @@
 #include <libaudcore/hook.h>
 #include <libaudcore/mainloop.h>
 #include <libaudcore/playlist.h>
+#include <libaudqt/dock.h>
 
 #include "../ui-common/dialogs-qt.h"
 
@@ -31,11 +32,10 @@
 class InfoBar;
 class PlaylistTabs;
 class PluginHandle;
-class PluginWidget;
 class QVBoxLayout;
 class StatusBar;
 
-class MainWindow : public QMainWindow
+class MainWindow : public QMainWindow, audqt::DockHost
 {
 public:
     MainWindow();
@@ -52,7 +52,6 @@ private:
     StatusBar * m_statusbar;
 
     PluginHandle *m_search_tool, *m_playlist_manager;
-    Index<PluginWidget *> m_dock_widgets;
 
     QAction *m_menu_action, *m_search_action;
     QAction *m_play_pause_action, *m_stop_action, *m_stop_after_action;
@@ -62,8 +61,8 @@ private:
     QueuedFunc m_buffering_timer;
     Playlist m_last_playing;
 
-    void closeEvent(QCloseEvent * e);
-    void keyPressEvent(QKeyEvent * event);
+    void closeEvent(QCloseEvent * e) override;
+    void keyPressEvent(QKeyEvent * event) override;
 
     void read_settings();
     void set_title(const QString & title);
@@ -73,17 +72,15 @@ private:
 
     void title_change_cb();
     void playback_begin_cb();
-    void buffering_cb();
     void playback_ready_cb();
     void pause_cb();
     void playback_stop_cb();
 
-    PluginWidget * find_dock_plugin(PluginHandle * plugin);
     void show_dock_plugin(PluginHandle * plugin);
-    void add_dock_plugin_cb(PluginHandle * plugin);
-    void remove_dock_plugin_cb(PluginHandle * plugin);
-    void add_dock_plugins();
-    void remove_dock_plugins();
+
+    void add_dock_item(audqt::DockItem * item) override;
+    void focus_dock_item(audqt::DockItem * item) override;
+    void remove_dock_item(audqt::DockItem * item) override;
 
     void show_search_tool()
     {
@@ -102,8 +99,8 @@ private:
         return true;
     }
 
-    const HookReceiver<MainWindow> hook1{"title change", this,
-                                         &MainWindow::title_change_cb},
+    const HookReceiver<MainWindow> //
+        hook1{"title change", this, &MainWindow::title_change_cb},
         hook2{"playback begin", this, &MainWindow::playback_begin_cb},
         hook3{"playback ready", this, &MainWindow::title_change_cb},
         hook4{"playback pause", this, &MainWindow::pause_cb},
@@ -120,11 +117,6 @@ private:
         hook15{"qtui show search tool", this, &MainWindow::show_search_tool},
         hook16{"qtui show playlist manager", this,
                &MainWindow::show_playlist_manager};
-
-    const HookReceiver<MainWindow, PluginHandle *> plugin_hook1{
-        "dock plugin enabled", this, &MainWindow::add_dock_plugin_cb},
-        plugin_hook2{"dock plugin disabled", this,
-                     &MainWindow::remove_dock_plugin_cb};
 };
 
 #endif
