@@ -187,6 +187,7 @@ QMenuBar * qtui_build_menubar(QWidget * parent)
         audqt::MenuCommand({N_("By _File Path")}, sort_path),
         audqt::MenuCommand({N_("By _Custom Title")}, sort_custom_title),
         audqt::MenuCommand({N_("By C_omment")}, sort_comment),
+        audqt::MenuCommand({N_("By D_isc Number")}, sort_disc),
         audqt::MenuSep(),
         audqt::MenuCommand({N_("R_everse Order"), "view-sort-descending"},
                            sort_reverse),
@@ -204,6 +205,7 @@ QMenuBar * qtui_build_menubar(QWidget * parent)
         audqt::MenuCommand({N_("By _File Path")}, sort_sel_path),
         audqt::MenuCommand({N_("By _Custom Title")}, sort_sel_custom_title),
         audqt::MenuCommand({N_("By C_omment")}, sort_sel_comment),
+        audqt::MenuCommand({N_("By D_isc Number")}, sort_sel_disc),
         audqt::MenuSep(),
         audqt::MenuCommand({N_("R_everse Order"), "view-sort-descending"},
                            sort_sel_reverse),
