@@ -39,17 +39,18 @@ enum {
 
 /* Drag data format listing for gtk_drag_dest_set() */
 static const GtkTargetEntry drop_types[] = {
-    {"text/plain", 0, DROP_PLAINTEXT},
-    {"text/uri-list", 0, DROP_URLENCODED},
-    {"STRING", 0, DROP_STRING},
-    {"interface/x-winamp-skin", 0, DROP_SKIN},
-    {"application/x-font-ttf", 0, DROP_FONT},
+    {(char *) "text/plain", 0, DROP_PLAINTEXT},
+    {(char *) "text/uri-list", 0, DROP_URLENCODED},
+    {(char *) "STRING", 0, DROP_STRING},
+    {(char *) "interface/x-winamp-skin", 0, DROP_SKIN},
+    {(char *) "application/x-font-ttf", 0, DROP_FONT},
 };
 
 static inline void drag_dest_set (GtkWidget * widget)
 {
-    gtk_drag_dest_set (widget, GTK_DEST_DEFAULT_MOTION | GTK_DEST_DEFAULT_DROP,
-     drop_types, ARRAY_LEN (drop_types), GDK_ACTION_COPY | GDK_ACTION_MOVE);
+    gtk_drag_dest_set (widget, (GtkDestDefaults) (GTK_DEST_DEFAULT_MOTION |
+     GTK_DEST_DEFAULT_DROP), drop_types, aud::n_elems (drop_types),
+     (GdkDragAction) (GDK_ACTION_COPY | GDK_ACTION_MOVE));
 }
 
 #endif /* SKINS_DND_H */
