@@ -151,6 +151,8 @@ static void read_comment (vorbis_comment * comment, Tuple & tuple)
         tuple.set_int (Tuple::Track, atoi (tmps));
     if ((tmps = vorbis_comment_query (comment, "DATE", 0)))
         tuple.set_int (Tuple::Year, atoi (tmps));
+    if ((tmps = vorbis_comment_query (comment, "DISCNUMBER", 0)))
+        tuple.set_int (Tuple::Disc, atoi (tmps));
 }
 
 /* try to detect when metadata has changed */
